@@ -61,6 +61,7 @@ class pub(object):
          'config_done',
          'custom_params_doc',
          'custom_typed_data',
+         'node_server_info',
          ]
 
     topics = {}
@@ -110,6 +111,7 @@ class Interface(object):
     CONFIGDONE        = 14
     CUSTOMPARAMSDOC   = 15
     CUSTOMTYPEDDATA   = 16
+    NSINFO            = 17
 
     """
     Polyglot Interface Class
@@ -155,7 +157,7 @@ class Interface(object):
         self._mqttc.on_log = self._log
         self.useSecure = True
         self._nodes = {}
-        self.nodes = {}
+        self.nodes_internal = {}
         if self.pg3init['secure'] == 1:
             self.sslContext = ssl.SSLContext(ssl.PROTOCOL_TLSv1_2)
             self.sslContext.check_hostname = False
@@ -188,8 +190,12 @@ class Interface(object):
 
         # attempt to build a list of node server custom classes
         self._nodeClasses = {}
-        for c in classes:
-            self._nodeClasses[c.id] = c
+        if type(classes) is list:
+            for c in classes:
+                try:
+                    self._nodeClasses[c.id] = c
+                except:
+                    LOGGER.error('Invalid class in initial class list')
 
     def subscribe(self, topic, callback, address=None):
         pub.subscribe(topic, callback, address)
@@ -250,7 +256,7 @@ class Interface(object):
                          'status', 'shortPoll', 'longPoll', 'delete',
                          'config', 'customdata', 'customparams', 'notices',
                          'getIsyInfo', 'getAll', 'setLogLevel',
-                         'customtypeddata', 'customtypedparams']
+                         'customtypeddata', 'customtypedparams', 'getNsInfo']
 
             parsed_msg = json.loads(msg.payload.decode('utf-8'))
             #LOGGER.debug('MQTT Received Message: {}: {}'.format(msg.topic, parsed_msg))
@@ -480,7 +486,7 @@ class Interface(object):
         list?
 
         self._nodes[address] = node properties from config
-        self.nodes[address] = a node object?
+        self.nodes_internal[address] = a node object?
                       - Added by addNode() or updateNode()
                       - addNode will copy driver values from _nodes and
                         replace the default values before sending to core
@@ -496,8 +502,8 @@ class Interface(object):
                 if the node is already in the main node list, use the values
                 from the database to update the node.
                 """
-                if node['address'] in self.nodes:
-                    n = self.nodes[node['address']]
+                if node['address'] in self.nodes_internal:
+                    n = self.nodes_internal[node['address']]
                     n.updateDrivers(node['drivers']) 
                     n.config = node
                     n.isPrimary = node['isPrimary']
@@ -517,6 +523,11 @@ class Interface(object):
                 NLOGGER.setLevel('DEBUG')
                 ILOGGER.setLevel('DEBUG')
                 self.currentLogLevel = 'DEBUG'
+            else:
+                LOGGER.setLevel(self.currentLogLevel)
+                CLOGGER.setLevel(self.currentLogLevel)
+                NLOGGER.setLevel(self.currentLogLevel)
+                ILOGGER.setLevel(self.currentLogLevel)
 
             GLOBAL_LOGGER.setLevel(self.currentLogLevel)
             level = logging.getLevelName(self.currentLogLevel)
@@ -606,6 +617,8 @@ class Interface(object):
             pub.publish(self.NOTICES, None, value)
         elif key == 'getIsyInfo':
             pub.publish(self.ISY, None, item)
+        elif key == 'getNsInfo':
+            pub.publish(self.NSINFO, None, item)
         elif key == 'getAll':
             """
             This is one of the first messages we get from Polyglot.
@@ -640,9 +653,9 @@ class Interface(object):
             except ValueError as e:
                 LOGGER.error('Failure trying to load {} data'.format(item.get('key')))
         elif key == 'command':
-            if item['address'] in self.nodes:
+            if item['address'] in self.nodes_internal:
                 try:
-                    self.nodes[item['address']].runCmd(item)
+                    self.nodes_internal[item['address']].runCmd(item)
                 except (Exception) as err:
                     LOGGER.error('_parseInput: failed {}.runCmd({}) {}'.format(
                         item['address'], item['cmd'], err), exc_info=True)
@@ -657,14 +670,14 @@ class Interface(object):
         elif key == 'longPoll':
             pub.publish(self.POLL, None, 'longPoll')
         elif key == 'query':
-            if item['address'] in self.nodes:
-                self.nodes[item['address']].query()
+            if item['address'] in self.nodes_internal:
+                self.nodes_internal[item['address']].query()
             elif item['address'] == 'all':
                 # TODO: FIXME: This isn't right now
                 self.query()
         elif key == 'status':
-            if item['address'] in self.nodes:
-                self.nodes[item['address']].status()
+            if item['address'] in self.nodes_internal:
+                self.nodes_internal[item['address']].status()
             elif item['address'] == 'all':
                 # TODO: FIXME: This isn't right now
                 self.status()
@@ -716,7 +729,7 @@ class Interface(object):
                 # Notify listeners that node has been added
                 pub.publish(self.ADDNODEDONE, None, result)
             #else:
-            #    del self.nodes[result.get('address')]
+            #    del self.nodes_internal[result.get('address')]
         except (KeyError, ValueError) as err:
             LOGGER.error('handleResult: {}'.format(err), exc_info=True)
 
@@ -739,6 +752,7 @@ class Interface(object):
         LOGGER.debug('Asking PG3 for config/getAll now')
         self.send({'config': {}}, 'system')
         self.send({'getAll': {}}, 'custom')
+        self.send({'getNsInfo': {}},'system')
 
     def isConnected(self):
         """ Tells you if this nodeserver and Polyglot are connected via MQTT """
@@ -764,7 +778,7 @@ class Interface(object):
         }
         self.send(message, 'command')
         self._nodes[node.address] = node
-        self.nodes[node.address] = node
+        self.nodes_internal[node.address] = node
 
         """
         This is too early to call the node's start function. At this point
@@ -783,15 +797,15 @@ class Interface(object):
 
         Is this an array or a dictionary keyed with address?
         """
-        return self.nodes
+        return self.nodes_internal
 
     def getNode(self, address):
         """
         Get Node by Address of existing nodes. 
         """
         try:
-            if address in self.nodes:
-                    return self.nodes[address]
+            if address in self.nodes_internal:
+                    return self.nodes_internal[address]
             return None
         except KeyError:
             LOGGER.error(
@@ -1029,8 +1043,8 @@ class Interface(object):
         self.send(message, 'system')
 
     def nodes(self):
-        for n in self.nodes:
-            yield self.nodes[n]
+        for n in self.nodes_internal:
+            yield self.nodes_internal[n]
 
     def supports_feature(self, feature):
         LOGGER.warning('The supports_feature() function is deprecated.')
